import { Notifier } from "./notifier";
import { InternalMessage, JoinedRoom, LeftRoom, ParticipantRenamed, ParticipantRole, RoomEvent, RoomState, UserId, UserNickname, StatsType, TrackType } from "./constants";
import { Connection } from "./connection";
import { WebRTCStats } from "./webrtc-stats";
import Logger from "./logger";
import { Mutex } from 'async-mutex';
export declare class Room {
    #private;
    protected notifier: Notifier<RoomEvent, InternalMessage>;
    protected connection: Connection;
    _id: string;
    _name: string;
    _userId: string;
    _pin: string;
    _nickname: string;
    protected logger: Logger;
    _uid: string;
    _crutch: {
        mutex: Mutex;
        tid: string;
    };
    protected stats: WebRTCStats;
    constructor(connection: Connection, name: string, pin: string, nickname: UserNickname, creationTime: number, userId?: UserId);
    processEvent(e: InternalMessage): Promise<void>;
    join(pc: RTCPeerConnection, nickname?: UserNickname, config?: {
        [key: string]: string;
    }, predefinedTracksCount?: number): Promise<JoinedRoom>;
    updateState(config?: {
        [key: string]: string;
    }): Promise<void>;
    destroyRoom(): Promise<void>;
    leaveRoom(): Promise<LeftRoom>;
    evictParticipant(userId: UserId): Promise<void>;
    renameParticipant(userId: UserId, newNickname: UserNickname): Promise<ParticipantRenamed>;
    sendMessage(msg: string): Promise<void>;
    changeQuality(trackId: string, quality: string, tid: number): Promise<void>;
    muteTrack(trackId: string, mute: boolean): Promise<void>;
    private muteRemoteTrack;
    on(event: RoomEvent, callback: (arg0: InternalMessage) => void): Room;
    off(event: RoomEvent, callback: (arg0: InternalMessage) => void): Room;
    id(): string;
    name(): string;
    userId(): string;
    pin(): string;
    nickname(): string;
    pc(): RTCPeerConnection;
    role(): ParticipantRole;
    invite(): string;
    state(): RoomState;
    creationTime(): number;
    getStats(track: MediaStreamTrack, type: StatsType, callback: Function): void;
    getRemoteTrack(kind: TrackType, force: boolean): Promise<RemoteTrack | undefined>;
}
export interface RemoteTrack {
    readonly track: MediaStreamTrack;
    readonly preferredQuality?: string;
    readonly tid?: number;
    readonly sid?: number;
    readonly disposed: boolean;
    demandTrack(remoteMid?: string): Promise<void>;
    mute(): Promise<void>;
    unmute(): Promise<void>;
    setPreferredQuality(quality?: string): Promise<void>;
    setSid(sid: number): Promise<void>;
    setTid(tid: number): Promise<void>;
    dispose(): Promise<void>;
}
